@@ -11,6 +11,8 @@ from qubell.api.globals import QUBELL as qubell_config
 class Router(object):
     def __init__(self, base_url=None, verify_ssl=False, verify_codes=True):
         self.base_url = base_url or qubell_config['tenant']
+        if self.base_url.endswith("/"):
+            self.base_url = self.base_url[:-1]
         self.verify_ssl = verify_ssl
         self.verify_codes = verify_codes
 
@@ -141,8 +143,8 @@ class PrivatePath(Router):
     def get_revisions(self, org_id, app_id, cookies, ctype=".json"): pass
 
     @play_auth
-    @route("DELETE /organizations/{org_id}/applications/{app_id}/revisions/{rev_id}{ctype}")
-    def delete_revision(self, org_id, app_id, rev_id, cookies, data="{}", ctype=".json"): pass
+    @route("DELETE /organizations/{org_id}/applications/{app_id}/revisions/{rev_id}{ctype}?force={force}")
+    def delete_revision(self, org_id, app_id, rev_id, cookies, data="{}", force="true", ctype=".json"): pass
 
     @play_auth
     @route("DELETE /organizations/{org_id}/applications/{app_id}/destroyedInstances{ctype}")
@@ -206,11 +208,11 @@ class PrivatePath(Router):
     def post_instance_reschedule(self, org_id, instance_id, workflow_id, data, cookies, ctype=".json"): pass
 
     @play_auth
-    @route("GET /organizations/{org_id}/runtime-components/{component_id}{ctype}")
+    @route("GET /organizations/{org_id}/runtimeComponents/{component_id}{ctype}")
     def get_component_details(self, org_id, component_id, cookies, ctype=".json"): pass
 
     @play_auth
-    @route("GET /organizations/{org_id}/runtime-components{ctype}")
+    @route("GET /organizations/{org_id}/runtimeComponents{ctype}")
     def get_components(self, org_id, cookies, params=None, ctype=".json"): pass
 
     #Environment
@@ -347,6 +349,9 @@ class PrivatePath(Router):
         pass
 
 
+# TODO: We shouldn't use subclassing to substitute private API for public API. Instead we should
+# TODO: use a flag inside the client to distinguish between APIs and select the approprate methods to call
+# TODO: inside the client itself.
 class PublicPath(PrivatePath):
 # TODO: Public api hack.
 # We replace private routes with public ones. Fixing response reaction in code.
@@ -399,6 +404,114 @@ class PublicPath(PrivatePath):
     @route("GET /api/1/organizations/{org_id}/environments")
     def get_environments(self, org_id, auth): pass
 
+    # Above methods are kept for backwards compatibility; when/if the client is refactored,
+    # they should go away, as well as the extension of `PrivatePath`.
+
+    # Applications
+
+    @basic_auth
+    @route("POST /api/1/applications/{app_id}/launch")
+    def api1_application_launch(self, app_id, json, auth): pass
+
+    @basic_auth
+    @route("PUT /api/1/applications/{app_id}/manifest")
+    def api1_application_put_manifest(self, app_id, data, auth, content_type="yaml"): pass
+
+    @basic_auth
+    @route("GET /api/1/applications/{app_id}/revisions")
+    def api1_application_list_revisions(self, app_id, auth): pass
+
+    # Instances
+
+    @basic_auth
+    @route("GET /api/1/instances/{instance_id}")
+    def api1_instance_details(self, instance_id, auth): pass
+
+    @basic_auth
+    @route("DELETE /api/1/instances/{instance_id}")
+    def api1_instance_delete(self, instance_id, auth, params): pass
+
+    @basic_auth
+    @route("POST /api/1/instances/{instance_id}/destroy")
+    def api1_instance_run_destroy(self, instance_id, auth, json): pass
+
+    @basic_auth
+    @route("POST /api/1/instances/{instance_id}/{workflow}")
+    def api1_instance_run_workflow(self, instance_id, workflow, auth, json): pass
+
+    @basic_auth
+    @route("PUT /api/1/instances/{instance_id}/userData")
+    def api1_instance_set_user_data(self, instance_id, json, auth): pass
+
+    # Environments
+
+    @basic_auth
+    @route("GET /api/1/environments/{env_id}")
+    def api1_environment_export(self, env_id, auth): pass
+
+    @basic_auth
+    @route("PUT /api/1/environments/{env_id}")
+    def api1_environment_import(self, env_id, json, auth): pass
+
+    @basic_auth
+    @route("GET /api/1/environments/{env_id}/instances")
+    def api1_environment_list_instances(self, env_id, auth): pass
+
+    @basic_auth
+    @route("GET /api/1/environments/{env_id}/markers")
+    def api1_environment_list_markers(self, env_id, auth): pass
+
+    @basic_auth
+    @route("PUT /api/1/environments/{env_id}/properties")
+    def api1_environment_update_markers(self, env_id, json, auth): pass
+
+    @basic_auth
+    @route("GET /api/1/environments/{env_id}/properties")
+    def api1_environment_list_properties(self, env_id, auth): pass
+
+    @basic_auth
+    @route("PUT /api/1/environments/{env_id}/properties")
+    def api1_environment_update_properties(self, env_id, json, auth): pass
+
+    # Organizations
+
+    @basic_auth
+    @route("POST /api/1/organizations/{org_id}/serviceTypes")
+    def api1_organization_create_service_type(self, org_id, json, auth): pass
+
+    @basic_auth
+    @route("GET /api/1/organizations/{org_id}/applications")
+    def api1_organization_list_applications(self, org_id, auth): pass
+
+    @basic_auth
+    @route("GET /api/1/organizations/{org_id}/environments")
+    def api1_organization_list_environments(self, org_id, auth): pass
+
+    @basic_auth
+    @route("GET /api/1/organizations")
+    def api1_organization_list(self, auth): pass
+
+    # Revisions
+
+    @basic_auth
+    @route("GET /api/1/revisions/{rev_id}/instances")
+    def api1_revision_list_instances(self, rev_id, auth): pass
+
+    # Services
+
+    @basic_auth
+    @route("GET /api/1/services/{service_id}")
+    def api1_service_get(self, service_id, auth): pass
+
+    @basic_auth
+    @route("PUT /api/1/services/{service_id}")
+    def api1_service_update(self, service_id, json, auth): pass
+
+    @basic_auth
+    @route("POST /api/1/services/{service_id}/{command}")
+    def api1_service_execute(self, service_id, command, json, auth): pass
+
+
 # TODO: Public api hack.
 # To use public api routes, set QUBELL_USE_PUBLIC env to not None
 if os.environ.get('QUBELL_USE_PUBLIC', None):
