@@ -4,6 +4,7 @@ import unittest
 import functools
 import nose.plugins.attrib
 import testtools
+import os
 
 
 from qubell.api.private.platform import QubellPlatform
@@ -23,6 +24,14 @@ __all__ = ['BaseComponentTestCase', 'applications', 'environment', 'environments
            'eventually', 'attr', 'unique']
 
 
+logger = log.getLogger("qubell")
+if os.getenv('QUBELL_LOG_LEVEL', 'info') == 'debug':
+    log.getLogger().setLevel(log.DEBUG)
+    logger.setLevel(log.DEBUG)
+else:
+    log.getLogger().setLevel(log.INFO)
+    logger.setLevel(log.INFO)
+
 class Qubell(object):
     """
     This class holds platform object.
@@ -44,13 +53,6 @@ class Qubell(object):
 
 class BaseComponentTestCase(SandBoxTestCase):
     parameters = dict(qubell_config.items() + cloud_config.items())
-    apps = []
-
-    @classmethod
-    def environment(cls, organization):
-        base_env = super(BaseComponentTestCase, cls).environment(organization)
-        base_env['applications'] = cls.apps or cls.applications
-        return base_env
 
     def setup_once(self):
         self.platform = Qubell.platform()
